==> percona-xtrabackup-8.3.0-1.tar.gz: percona-xtrabackup-8.3.0-1/storage/ndb/include/kernel/signaldata/SignalDataPrint.hpp <==
/*
   Copyright (c) 2003, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef SIGNAL_DATA_PRINT_H
#define SIGNAL_DATA_PRINT_H

#include <kernel_types.h>
#include <ndb_global.h>

#define JAM_FILE_ID 41

/**
 * Typedef for a Signal Data Print Function
 */
typedef bool (*SignalDataPrintFunction)(FILE *output, const Uint32 *theData,
                                        Uint32 len,
                                        BlockNumber receiverBlockNo);

struct NameFunctionPair {
  GlobalSignalNumber gsn;
  SignalDataPrintFunction function;
};

extern const NameFunctionPair SignalDataPrintFunctions[];
extern const unsigned short NO_OF_PRINT_FUNCTIONS;

#undef JAM_FILE_ID

#endif

==> percona-xtrabackup-80_8.0.35-34.orig.tar.gz: percona-xtrabackup-8.0.35-34/storage/ndb/include/kernel/signaldata/SignalDataPrint.hpp <==
/*
   Copyright (c) 2003, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef SIGNAL_DATA_PRINT_H
#define SIGNAL_DATA_PRINT_H

#include <ndb_global.h>
#include <kernel_types.h>

#define JAM_FILE_ID 41


/**
 * Typedef for a Signal Data Print Function
 */
typedef bool (* SignalDataPrintFunction)(FILE * output, const Uint32 * theData, Uint32 len, BlockNumber receiverBlockNo);

struct NameFunctionPair {
  GlobalSignalNumber gsn;
  SignalDataPrintFunction function;
};

extern const NameFunctionPair SignalDataPrintFunctions[];
extern const unsigned short   NO_OF_PRINT_FUNCTIONS;


#undef JAM_FILE_ID

#endif
